import React from 'react';
import Page from '@/components/Page';
import { useNavigate, Link } from 'react-router-dom';
import { queryTable } from "@/utils/request";
import { ProTable, ModalForm, ProFormText } from "@ant-design/pro-components";
import { Button, message, Popconfirm, Form } from "antd";
import { getTaCheck, deleteTaCheck, putTaCheck, calcScoreTaCheck } from '@/service/tacheck';
import CopyCheck from './components/CopyCheck';

const queryList = queryTable(getTaCheck);

export default (props) => {

  const navigate = useNavigate();
  const actionRef = React.useRef();
  const [messageApi, contextHolder] = message.useMessage();
  const [open, setOpen] = React.useState(false);
  const [check, setCheck] = React.useState(false);

  const onDelete = (item) => {
    deleteTaCheck(item.checkId).then(() => {
      actionRef.current.reload();
    })
  }

  const onUpdateStatus = (item) => {
    putTaCheck(item.checkId, { ...item, status: Math.abs(item.status - 1) }).then(() => {
      actionRef.current.reload();
    })
  }

  const onCalc = (row) => {
    messageApi.open({
      type: 'loading',
      content: '正在计算, 请稍候...',
      duration: 0,
    });
    calcScoreTaCheck(row.checkId).then(() => {
      messageApi.destroy();
      actionRef.current.reload();
    }).catch(() => {
      messageApi.destroy();
    });
  }

  const onOpen = (record) => {
    setCheck(record);
    setOpen(true);
  }

  const onCopyFinish = () => {
    actionRef.current.reload();
  }

  const columns = [
    {
      title: "测评名称",
      dataIndex: "title",
      render: (_, row) => !row.title ? '-' : <Link to={`/check/edit?id=${row.checkId}`}>{row.title}</Link>,
    },
    {
      title: "测评日期",
      hideInTable: true,
      dataIndex: "dateRange",
      valueType: 'dateRange',
      search: {
        transform: value => ({ startDate: value[0], endDate: value[1] }),
      },
    },
    {
      title: "开始日期",
      dataIndex: "startDate",
      hideInSearch: true,
    },
    {
      title: "结束日期",
      dataIndex: "endDate",
      hideInSearch: true,
    },
    {
      title: "实地测评得分",
      dataIndex: "locScore",
      hideInSearch: true,
      render: (_, row) => {
        const origin = row.locScore || 0;
        const percent = row.locScorePercent || 0;
        const score = Number(origin * percent).toFixed(2);

        return `${origin} * ${percent * 100}% = ${score}`;
      },
    },
    {
      title: "调查问卷得分",
      dataIndex: "surveyScore",
      hideInSearch: true,
      render: (_, row) => {
        const num = row.surveyNum || 0;
        if (num === 0) return '-';

        const origin = row.surveyScore || 0;
        const percent = row.surveyScorePercent || 0;
        const score = Number(origin / num * percent).toFixed(2);

        return `${origin} / ${num} * ${percent * 100}% = ${score}`;
      },
    },
    {
      title: "状态",
      dataIndex: "status",
      search: false,
      valueEnum: {
        1: {
          text: "正常",
          status: "Processing",
        },
        0: {
          text: "禁用",
          status: "Error",
        },
      },
    },
    {
      title: "操作",
      valueType: "option",
      width: 240,
      render: (_, record) => [
        console.log('record', record),
        // <Button
        //   key={1}
        //   style={{ padding: 0 }}
        //   type="link"
        //   onClick={() => {
        //     onUpdateStatus(record);
        //   }}
        // >
        //   {record.status === 1 ? "禁用" : "启用"}
        // </Button>,
        <Popconfirm
          key={3}
          title="您是否确认删除 ?"
          onConfirm={() => onDelete(record)}
          okText="确定"
          cancelText="取消"
        >
          {/* manualPush */}
          <Button style={{ padding: 0 }} danger type="link">
            删除
          </Button>
        </Popconfirm>,
        <Popconfirm
          key={4}
          title="系统计算可能需要1分钟的时间"
          onConfirm={() => onCalc(record)}
          okText="确定"
          cancelText="取消"
        >
          {/* manualPush */}
          <Button style={{ padding: 0 }} type="link">
            计算分数
          </Button>
        </Popconfirm>,
        <Button type="link" key={5} onClick={() => { onOpen(record) }}>复制</Button>,
      ],
    },
  ]

  return (
    <Page>
      {contextHolder}
      <CopyCheck
        open={open}
        check={check}
        onOpenChange={setOpen}
        onFinish={onCopyFinish}
      />
      <ProTable
        actionRef={actionRef}
        rowKey="checkId"
        toolBarRender={() => [
          <Button
            key="1"
            type="primary"
            onClick={() => {
              navigate("/check/edit");
            }}
          >
            新增
          </Button>,
        ]}
        request={queryList}
        columns={columns}
      />
    </Page>
  )
}
