import React from 'react';
import { Modal, Form, Input, Button } from 'antd';
import useBool from '@/utils/hooks/useBool';
import { getSysLogin, postSysLogin } from '@/service/syslogin';
import md5 from 'md5';

const formItemLayout = {
  labelCol: {
    xs: { span: 24 },
    sm: { span: 8 },
  },
  wrapperCol: {
    xs: { span: 24 },
    sm: { span: 16 },
  },
};
const tailFormItemLayout = {
  wrapperCol: {
    xs: {
      span: 24,
      offset: 0,
    },
    sm: {
      span: 16,
      offset: 8,
    },
  },
};

const defaultPass = '123456';

export default (props) => {
  const { user, onSuccess, onCancel, ...leftProps } = props;

  const [loading, startLoading, cancelLoading] = useBool();
  const [form] = Form.useForm();
  const [account, setAccount] = React.useState();

  const onFinish = (values) => {
    const loginId = account ? account.loginId : undefined;
    const password = values.password ? md5(values.password) : (
      loginId ? undefined : md5(defaultPass)
    );

    const data = {
      ...values,
      password,
      loginId,
      userId: user.userId,
    }

    startLoading();
    postSysLogin(data).then(res => {
      onSuccess();
      cancelLoading();
    }).catch(() => {
      cancelLoading();
    });
  };

  React.useEffect(() => {
    if (user?.userId) {
      startLoading();
      getSysLogin(user.userId).then(res => {
        console.log('res', res)
        if (res) {
          setAccount(res);
          form.setFieldsValue(res);
        } else {
          form.setFieldsValue({ account: user.phone })
        }
        cancelLoading();
      }).catch((err) => {
        console.error(err)
        cancelLoading();
      });
    }
  }, [user, form])

  return (
    <Modal title="账号维护" footer={null} width={600} onCancel={onCancel} {...leftProps}>
      <Form {...formItemLayout} form={form} scrollToFirstError style={{ width: '480px' }} onFinish={onFinish}>
        <Form.Item
          name="account"
          label="账号"
          rules={[
            {
              required: true,
              message: '请填写姓名',
            },
          ]}
        >
          <Input />
        </Form.Item>
        <Form.Item
          name="password"
          label="密码"
          help={`默认密码 ${defaultPass}`}
        >
          <Input.Password allowClear/>
        </Form.Item>
          <Form.Item {...tailFormItemLayout}>
            <Button loading={loading} type="primary" htmlType="submit">
              保存
            </Button>
            <Button style={{ marginLeft: '2em' }} onClick={onCancel}>
              取消
            </Button>
          </Form.Item>
      </Form>
    </Modal>
  )
}
